@@ -18,8 +18,9 @@ class TestSpotifyChapter:
         assert from_uri(chapter.uri)[0] == "episode"
 
     def test_chapter_with_non_us_market_found(self, app_client):
-        with pytest.raises(NotFound):
-            app_client.chapter(chapter_id, market="FI")
+        chapter = app_client.chapter(chapter_id, market="FI")
+        assert chapter.id == chapter_id
+        assert from_uri(chapter.uri)[0] == "episode"
 
     @pytest.mark.xfail(reason="API inconsistencies.")
     def test_chapters_no_market_returns_none(self, app_client):
@@ -30,6 +31,6 @@ class TestSpotifyChapter:
         chapters = app_client.chapters(chapter_ids, market="US")
         assert chapter_ids == [c.id for c in chapters]
 
-    def test_chapters_non_us_market_returns_none(self, app_client):
+    def test_chapters_non_us_market_returns_results(self, app_client):
         chapters = app_client.chapters(chapter_ids, market="FI")
-        assert all(c is None for c in chapters)
+        assert chapter_ids == [c.id for c in chapters]
